@@ -29,6 +29,7 @@
 
 from __future__ import print_function
 
+import os
 import subprocess
 import traceback
 
@@ -293,7 +294,7 @@ class Installer(object):
             resolved2 = installer.resolve(args2)
             resolved = installer.unique(resolved1, resolved2)
 
-        :param *resolved_rules: resolved arguments.  Resolved
+        :param resolved_rules: resolved arguments.  Resolved
           arguments must all be from this :class:`Installer` instance.
         """
         raise NotImplementedError("Base class unique", resolved_rules)
@@ -314,11 +315,13 @@ class PackageManagerInstaller(Installer):
     def __init__(self, detect_fn, supports_depends=False):
         """
         :param supports_depends: package manager supports dependency key
+        :param detect_fn: function that for a given list of packages determines
+        the list of installed packages.
         """
         self.detect_fn = detect_fn
         self.supports_depends = supports_depends
         self.as_root = True
-        self.sudo_command = 'sudo -H'
+        self.sudo_command = 'sudo -H' if os.geteuid() != 0 else ""
 
     def elevate_priv(self, cmd):
         """
@@ -356,6 +359,10 @@ class PackageManagerInstaller(Installer):
         return sorted(list(s))
         
     def get_packages_to_install(self, resolved, reinstall=False):
+        '''
+        Return a list of packages (out of *resolved*) that still need to get
+        installed.
+        '''
         if reinstall:
             return resolved
         if not resolved:
@@ -364,8 +371,20 @@ class PackageManagerInstaller(Installer):
             return list(set(resolved) - set(self.detect_fn(resolved)))
 
     def is_installed(self, resolved_item):
+        '''
+        Check if a given package was installed.
+        '''
         return not self.get_packages_to_install([resolved_item])
 
+    def get_version_strings(self):
+        '''
+        Return a list of version information strings.
+
+        Where each string is of the form "<installer> <version string>".
+        For example, ["apt-get x.y.z"] or ["pip x.y.z", "setuptools x.y.z"].
+        '''
+        raise NotImplementedError('subclasses must implement get_version_strings method')
+
     def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         raise NotImplementedError('subclasses must implement', resolved, interactive, reinstall, quiet)
 
@@ -379,6 +398,18 @@ class PackageManagerInstaller(Installer):
             return rosdep_args.get('depends', [])
         return [] # Default return empty list
 
+
+def normalize_uninstalled_to_list(uninstalled):
+    uninstalled_dependencies = []
+    for pkg_or_list in [v for k, v in uninstalled]:
+        if isinstance(pkg_or_list, list):
+            for pkg in pkg_or_list:
+                uninstalled_dependencies.append(str(pkg))
+        else:
+            uninstalled_dependencies.append(str(pkg))
+    return uninstalled_dependencies
+
+
 class RosdepInstaller(object):
 
     def __init__(self, installer_context, lookup):
@@ -465,8 +496,12 @@ class RosdepInstaller(object):
             installer.install(uninstalled)
         """
         if verbose:
-            print("install options: reinstall[%s] simulate[%s] interactive[%s]"%(reinstall, simulate, interactive))
-            print("install: uninstalled keys are %s"%(', '.join([', '.join(pkg) for pkg in [v for k,v in uninstalled]])))
+            print(
+                "install options: reinstall[%s] simulate[%s] interactive[%s]" %
+                (reinstall, simulate, interactive)
+            )
+            uninstalled_list = normalize_uninstalled_to_list(uninstalled)
+            print("install: uninstalled keys are %s" % ', '.join(uninstalled_list))
 
         # Squash uninstalled again, in case some dependencies were already installed
         squashed_uninstalled = []
