@@ -59,7 +59,8 @@ import rospkg
 
 from . import create_default_installer_context, get_default_installer
 from . import __version__
-from .core import RosdepInternalError, InstallFailed, UnsupportedOs, InvalidData, CachePermissionError
+from .core import RosdepInternalError, InstallFailed, UnsupportedOs, InvalidData, CachePermissionError, DownloadFailure
+from .installers import normalize_uninstalled_to_list
 from .installers import RosdepInstaller
 from .lookup import RosdepLookup, ResolutionError
 from .rospkg_loader import DEFAULT_VIEW_KEY
@@ -264,7 +265,9 @@ def _rosdep_main(args):
     parser.add_option("--verbose", "-v", dest="verbose", default=False, 
                       action="store_true", help="verbose display")
     parser.add_option("--version", dest="print_version", default=False, 
-                      action="store_true", help="print version and exit")
+                      action="store_true", help="print just the rosdep version, then exit")
+    parser.add_option("--all-versions", dest="print_all_versions", default=False,
+                      action="store_true", help="print rosdep version and version of installers, then exit")
     parser.add_option("--reinstall", dest="reinstall", default=False, 
                       action="store_true", help="(re)install all dependencies, even if already installed")
     parser.add_option("--default-yes", "-y", dest="default_yes", default=False, 
@@ -274,7 +277,7 @@ def _rosdep_main(args):
     parser.add_option("-r", dest="robust", default=False, 
                       action="store_true", help="Continue installing despite errors.")
     parser.add_option("-q", dest="quiet", default=False, 
-                      action="store_true", help="Suprress output except for errors")
+                      action="store_true", help="Quiet. Suppress output except for errors.")
     parser.add_option("-a", "--all", dest="rosdep_all", default=False, 
                       action="store_true", help="select all packages")
     parser.add_option("-n", dest="recursive", default=True, 
@@ -306,7 +309,7 @@ def _rosdep_main(args):
     parser.add_option("--from-paths", dest='from_paths',
                       default=False, action="store_true",
                       help="Affects the 'check', 'keys', and 'install' verbs. "
-                           "If specified the arugments to those verbs will be "
+                           "If specified the arguments to those verbs will be "
                            "considered paths to be searched, acting on all "
                            "catkin packages found there in.")
     parser.add_option("--rosdistro", dest='ros_distro', default=None,
@@ -320,8 +323,35 @@ def _rosdep_main(args):
                       "Can be specified multiple times.")
 
     options, args = parser.parse_args(args)
-    if options.print_version:
-        print(__version__)
+    if options.print_version or options.print_all_versions:
+        # First print the rosdep version.
+        print('{}'.format(__version__))
+        # If not printing versions of all installers, exit.
+        if not options.print_all_versions:
+            sys.exit(0)
+        # Otherwise, Then collect the versions of the installers and print them.
+        installers = create_default_installer_context().installers
+        installer_keys = get_default_installer()[1]
+        version_strings = []
+        for key in installer_keys:
+            if key is 'source':
+                # Explicitly skip the source installer.
+                continue
+            installer = installers[key]
+            try:
+                installer_version_strings = installer.get_version_strings()
+                assert isinstance(installer_version_strings, list), installer_version_strings
+                version_strings.extend(installer_version_strings)
+            except NotImplementedError:
+                version_strings.append('{} unknown'.format(key))
+                continue
+        if version_strings:
+            print()
+            print("Versions of installers:")
+            print('\n'.join(['  ' + x for x in version_strings if x]))
+        else:
+            print()
+            print("No installers with versions available found.")
         sys.exit(0)
 
     # flatten list of skipped keys and filter-for-installers
@@ -487,6 +517,10 @@ def command_init(options):
     except URLError as e:
         print("ERROR: cannot download default sources list from:\n%s\nWebsite may be down."%(DEFAULT_SOURCES_LIST_URL))
         return 4
+    except DownloadFailure as e:
+        print("ERROR: cannot download default sources list from:\n%s\nWebsite may be down."%(DEFAULT_SOURCES_LIST_URL))
+        print(e)
+        return 4
     # reuse path variable for error message 
     path = get_sources_list_dir()
     old_umask = os.umask(0o022)
@@ -631,7 +665,8 @@ def command_install(lookup, packages, options):
         uninstalled, errors = installer.get_uninstalled(packages, implicit=options.recursive, verbose=options.verbose)
 
     if options.verbose:
-        print("uninstalled dependencies are: [%s]"%(', '.join([', '.join(pkg) for pkg in [v for k,v in uninstalled]])))
+        uninstalled_dependencies = normalize_uninstalled_to_list(uninstalled)
+        print("uninstalled dependencies are: [%s]" % ', '.join(uninstalled_dependencies))
 
     if errors:
         err_msg = ("ERROR: the following packages/stacks could not have their "
@@ -847,6 +882,3 @@ _command_rosdep_args = ['what-needs', 'what_needs', 'where-defined', 'where_defi
 _command_no_args = ['update', 'init', 'db', 'fix-permissions']
 
 _commands = command_handlers.keys()
-
-
-
