@@ -66,7 +66,7 @@ from .rosdistrohelper import get_index, get_index_url
 
 # default file to download with 'init' command in order to bootstrap
 # rosdep
-DEFAULT_SOURCES_LIST_URL = 'https://raw.github.com/ros/rosdistro/master/rosdep/sources.list.d/20-default.list'
+DEFAULT_SOURCES_LIST_URL = 'https://raw.githubusercontent.com/ros/rosdistro/master/rosdep/sources.list.d/20-default.list'
 
 #seconds to wait before aborting download of rosdep data
 DOWNLOAD_TIMEOUT = 15.0
@@ -309,7 +309,8 @@ def download_default_sources_list(url=DEFAULT_SOURCES_LIST_URL):
 
     :param url: override URL of default sources list file
     :return: raw sources list data, ``str``
-    :raises: :exc:`InvalidData`
+    :raises: :exc:`DownloadFailure` If data cannot be
+            retrieved (e.g. 404, bad YAML format, server down).
     :raises: :exc:`urllib2.URLError` If data cannot be
         retrieved (e.g. 404, server down).
     """
@@ -320,9 +321,14 @@ def download_default_sources_list(url=DEFAULT_SOURCES_LIST_URL):
     data = f.read().decode()
     f.close()
     if not data:
-        raise RuntimeError("cannot download defaults file: empty contents")
+        raise DownloadFailure("cannot download defaults file from %s : empty contents" % url)
     # parse just for validation
-    parse_sources_data(data)
+    try:
+        parse_sources_data(data)
+    except InvalidData as e:
+        raise DownloadFailure("The content downloaded from %s failed to pass validation."
+            " It is likely that the source is invalid unless the data was corrupted during the download."
+            " The contents were:{{{%s}}} The error raised was: %s" % (url, data, e))
     return data
 
 def parse_sources_data(data, origin='<string>', model=None):
